<?php

/**
 * Handles user meta data.
 *
 *
 * @link       http://www.servicetrade.com
 * @since      2.0.0
 * @package    Servicetrade_Service_Portal
 * @subpackage Servicetrade_Service_Portal/includes
 * @author     ServiceTrade <support@servicetrade.com>
 */
class Servicetrade_User_Meta {

  /**
	 * Adds the user meta data when the user is created.
	 *
	 * @since     2.0.0
	 */
  public static function set_user_meta_data($user_id, 
                                          $user_status,
                                          $can_request_service,
                                          $can_view_quotes,
                                          $can_view_deficiencies,
                                          $can_view_prices) {

    static::set_status($user_id, $user_status);

    /*
    update_user_meta(
      $user_id,
      "servicetrade_portal_user_status",
      $user_status
    ); */

    update_user_meta(
      $user_id,
      "servicetrade_portal_can_request_service",
      $can_request_service
    );

    update_user_meta(
      $user_id,
      "servicetrade_portal_can_view_quotes",
      $can_view_quotes
    );

    update_user_meta(
      $user_id,
      "servicetrade_portal_can_view_deficiencies",
      $can_view_deficiencies
    );
    update_user_meta(
      $user_id,
      "servicetrade_portal_can_view_prices",
      $can_view_prices
    );
  }

  public static function set_status($user_id, 
      $user_status) {
    update_user_meta(
      $user_id,
      "servicetrade_portal_user_status",
      $user_status
    );
  }

  public static function get_status($user_id) {
    return get_user_meta(
      $user_id,
      "servicetrade_portal_user_status",
      true
    );
  }


  public static function set_can_request_service($user_id, $value) {
    update_user_meta(
      $user_id,
      "servicetrade_portal_can_request_service",
      $value
    );
  }

  public static function get_can_request_service($user_id) {
    return static::clean_boolean(get_user_meta(
      $user_id,
      "servicetrade_portal_can_request_service",
      true
    ));
  }

  public static function set_can_view_quotes($user_id, $value) {
    update_user_meta(
      $user_id,
      "servicetrade_portal_can_view_quotes",
      $value
    );
  }
  public static function get_can_view_quotes($user_id) {
    return static::clean_boolean(get_user_meta(
      $user_id,
      "servicetrade_portal_can_view_quotes",
      true
    ));
  }

  public static function set_can_view_deficiencies($user_id, $value) {
    update_user_meta(
      $user_id,
      "servicetrade_portal_can_view_deficiencies",
      $value
    );
  }
  public static function get_can_view_deficiencies($user_id) {
    return static::clean_boolean(get_user_meta(
      $user_id,
      "servicetrade_portal_can_view_deficiencies",
      true
    ));
  }
  public static function set_can_view_prices($user_id, $value) {
    update_user_meta(
      $user_id,
      "servicetrade_portal_can_view_prices",
      $value
    );
  }

  public static function get_can_view_prices($user_id) {
    return static::clean_boolean(get_user_meta(
      $user_id,
      "servicetrade_portal_can_view_prices",
      true
    ));
  }


  /**
   * @param string @user_id - the id of the user who's cache value we want to retrieve
   * @param object $value - the cached data.
   * @since     2.0.5
   */
  public static function set_locations_cache($user_id, $value) {
    update_user_meta(
      $user_id,
      "servicetrade_portal_locations_cache",
      $value ? json_encode($value) : null
    );
  }

  /**
   * 
   * @param string @user_id - the id of the user who's cache value we want to retrieve
   * @since     2.0.5
   */
  public static function get_locations_cache($user_id) {
    $result = get_user_meta(
      $user_id,
      "servicetrade_portal_locations_cache",
      true
    );
    
    return $result ? json_decode($result,true) : null;
  }


  private static function clean_boolean($resultAsString) {
    return $resultAsString === '1' || $resultAsString === 'true';
  }
  
  
}
