<?php


/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Servicetrade_Service_Portal
 * @subpackage Servicetrade_Service_Portal/public
 * @author     ServiceTrade <support@servicetrade.com>
 */
class Servicetrade_Service_Portal_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $Servicetrade_Service_Portal    The ID of this plugin.
	 */
	private $Servicetrade_Service_Portal;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $Servicetrade_Service_Portal       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $Servicetrade_Service_Portal, $version ) {

		$this->Servicetrade_Service_Portal = $Servicetrade_Service_Portal;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Servicetrade_Service_Portal_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Servicetrade_Service_Portal_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style(  'servicetrade-service-portal-jquery-datatables-css', plugin_dir_url( __FILE__ ) . 'css/jquery.dataTables.min.css', array(), $this->version, 'all' );		
		wp_enqueue_style( 'servicetrade-service-portal-public', plugin_dir_url( __FILE__ ) . 'css/servicetrade-portal-public.css', array(), $this->version, 'all' );
		wp_enqueue_style( 'servicetrade-service-portal-public-main-react-css', plugin_dir_url( __FILE__ ) . 'css/main.react.css', array(), $this->version, 'all' );
		
	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Servicetrade_Service_Portal_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Servicetrade_Service_Portal_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		 wp_enqueue_script('jquery'); // Probably not needed at all 

		 wp_enqueue_script( 'servicetrade-service-portal-jquery-datatables', plugin_dir_url( __FILE__ ) . 'js/jquery.dataTables.min.js', array( 'jquery' ), $this->version, false );
		 wp_enqueue_script( 'servicetrade-service-portal-jquery-datatables-conditionalpaging', plugin_dir_url( __FILE__ ) . 'js/dataTables.conditionalPaging.js ', array( 'jquery' ), $this->version, false );
		 wp_enqueue_script( 'servicetrade-service-portal-jquery-ui', plugin_dir_url( __FILE__ ) . 'js/jquery-ui.min.js', array( 'jquery' ), $this->version, false );
		 wp_enqueue_script( 'servicetrade-service-portal-jquery-succinct', plugin_dir_url( __FILE__ ) . 'js/jquery.succinct.min.js', array( 'jquery' ), $this->version, false );
  	    wp_enqueue_script( 'servicetrade-service-portal-jquery-popupoverlay', plugin_dir_url( __FILE__ ) . 'js/jquery.popupoverlay.js', array( 'jquery' ), $this->version, false );
		 wp_enqueue_script( 'servicetrade-service-portal-public', plugin_dir_url( __FILE__ ) . 'js/servicetrade-portal-public.js', array( 'jquery' ), $this->version, false );
		 wp_enqueue_script( 'servicetrade-service-portal-public-widget-login', plugin_dir_url( __FILE__ ) . 'js/servicetrade-portal-public-widget-login.js', array( 'jquery' ), $this->version, false );
		 wp_enqueue_script( 'servicetrade-service-portal-public-main-rest', plugin_dir_url( __FILE__ ) . 'js/main.react.js', array( 'jquery' ), $this->version, true );
		}

	/**
	 * Registers the public widgets.
	 *
	 * @since    1.0.0
	 */
	public function register_widgets() {
		require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'public/widgets/class-servicetrade-login-widget.php';
		register_widget('Servicetrade_Service_Portal_Login_Widget');
	} 

	public function shortcode_servicetrade( $atts, $content = null ) {
		require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'public/controllers/class-shortcode-servicetrade-controller.php';

		$controller = new Servicetrade_Service_Portal_Public_Shortcode_Servicetrade_Controller();
		$controller->render();
	}


	public function register_rest_controllers() {
		require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'public/rest/class-public-routes-controller.php';
		
		$routes = new Servicetrade_Service_Portal_Public_Routes_Controller();
		$routes->register_routes();
	}

}
