(function( $ ) {
	'use strict';

  var buildUrl = function(path) {
    return window.servicetradePortalConfig ? window.servicetradePortalConfig.apiRoot + path : path;
  };

  var showLoginForm = function() {
    $('.servicetrade-widget-login-form-login').show();
    $('.servicetrade-widget-login-form-signup').hide();
    $('.servicetrade-widget-login-form-forgot-password').hide();
  };

  var showSignupForm = function() {
    $('.servicetrade-widget-login-form-login').hide();
    $('.servicetrade-widget-login-form-signup').show();
    $('.servicetrade-widget-login-form-forgot-password').hide();
  };

  var showForgotPasswordForm = function() {
    $('.servicetrade-widget-login-form-login').hide();
    $('.servicetrade-widget-login-form-signup').hide();
    $('.servicetrade-widget-login-form-forgot-password').show();
  };

  var onActionLogin = function(e){
    e.preventDefault();
    showLoginForm();
  };

  var onActionSignup = function(e){
    e.preventDefault();
    showSignupForm();
  };

  var onActionForgotPassword = function(e){
    e.preventDefault();
    showForgotPasswordForm();
  };

  var arrayToObject = function (unindexed_array){
    var indexed_array = {};
    $.map(unindexed_array, function(n, i){
        indexed_array[n['name']] = n['value'];
    });

    return indexed_array;
  }

  /**
   * Hides the three input forms.
   */
  var hideAllForms = function() {
    $('form.servicetrade-widget-login-form-login').hide();
    $('form.servicetrade-widget-login-form-signup').hide();
    $('form.servicetrade-widget-login-form-forgot-password').hide();

  };

  var hideSuccessError = function() {
    $('.servicetrade-success-container').hide();
    $('.servicetrade-error-container').hide();
  };

  var showError = function(message) {
    $('.servicetrade-success-container').hide();
    $('.servicetrade-error-container').html("<p>" + message + "</p>").show();
  };

  var showSuccess = function(message) {
    $('.servicetrade-error-container').hide();
    $('.servicetrade-success-container').html("<p>" + message + "</p>").show();
  };

  var performAjax = function(url,formData, success,fail) {
    $.ajax({
      type        : 'POST',
      data        : formData,
      url: url,
      dataType    : 'json',
      encode          : true
    })
    .done(success)
    .fail(fail);
  };

  /**
   * Attempts to sign the client in.
   * @param {Object} formData 
   */
  var performSignIn = function(formData) {
    var fnSuccessSignIn = function(result) {
      if(result.redirectUrl) {
        window.location = result.redirectUrl;
      }
    };
    var fnFailSignIn = function(error) {
      showError("Failed to sign you in. Please check that your username/email and password are correct and that you have been given access to the portal.");
    };

    performAjax(buildUrl('user/login'), formData,fnSuccessSignIn,fnFailSignIn);
  };

  /**
   * Attempts to request access for a new client
   * @param {Object} formData 
   */
  var performRequestAccess = function(formData) {
    var fnSuccessRequestAccess = function(result) {
        showSuccess("You have successfully requested access and will receive a confirmation email shortly.");
        hideAllForms();
      };
    var fnFailRequestAccess = function(error) {
		 var errorMessage = error && error.responseJSON && error.responseJSON.message ? error.responseJSON.message + '.' : '';
      showError("Could not request access. " + errorMessage);
    };

    performAjax(buildUrl('user/request-access'), formData,fnSuccessRequestAccess,fnFailRequestAccess);
  };

  /**
   * Attempts to retrieve the password for a client
   * @param {Object} formData 
   */
  var performForgotPassword = function(formData) {
    var fnSuccessForgotPassword = function(result) {
        showSuccess("Please check your email - you should receive password reset instructions shortly.");
        hideAllForms();
      };
    var fnFailForgotPassword = function(error) {
      showError("Could not send email: " + error.responseJSON.message);
    };

    performAjax(buildUrl('user/forgot-password'), formData,fnSuccessForgotPassword,fnFailForgotPassword);
  };

  var onSubmitForm = function(e) {
    e.preventDefault();
    hideSuccessError();
    var formData = $(e.target).find(":input").serializeArray();
    formData = arrayToObject(formData);
    // console.log(formData); 
    
    var url = '';
    switch(formData['action']) {
      case 'servicetrade-widget-login-form-login':
        return performSignIn(formData);
      case 'servicetrade-widget-login-form-signup':
        return performRequestAccess(formData);
      case 'servicetrade-widget-login-form-forgot-password':
        return performForgotPassword(formData);
    }

  }
  
  $(function() {
    $('.servicetrade-widget-login-form-action-login').click(onActionLogin);
    $('.servicetrade-widget-login-form-action-signup').click(onActionSignup);
    $('.servicetrade-widget-login-form-action-forgot-password').click(onActionForgotPassword);

    $('form.servicetrade-widget-login-form-login').submit(onSubmitForm);
    $('form.servicetrade-widget-login-form-signup').submit(onSubmitForm);
    $('form.servicetrade-widget-login-form-forgot-password').submit(onSubmitForm);
  });
})( jQuery );
