<?php

require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'includes/class-servicetrade-action.php';
require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'includes/class-servicetrade-helper-sideloadmapper.php';
require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'public/rest/class-public-rest-action.php';

/**
 * Returns the service requests belonging to an asset.
 *
 * @example
 * http://localhost:8888/wp-json/servicetrade-service-portal/v2/public/locations/1739987/servicerequests
 *
 * @link       http://www.servicetrade.com
 * @since      2.0.0
 * @package    Servicetrade_Service_Portal
 * @subpackage Servicetrade_Service_Portal/public/rest/actions
 * @author     ServiceTrade <support@servicetrade.com>
 */
class Servicetrade_Service_Portal_Public_Actions_Rest_Asset_Servicerequests_Get_Action extends Servicetrade_Service_Portal_Public_Rest_Action {
  private $id;
  
  function __construct($id) {
    assert($id !== null, "An id is required.");
    $this->id = $id;
  }

  function run() {
    $user = $this->get_authenticated_user();
    if(null === $user) {
			return $this->create_rest_error_not_authorized();
    }
		$contactId = $user->getContactId();

    $apiResult = $this->api_get($this->build_asset_service_requests_query());
    
    if(!isset( $apiResult['serviceRequests'] )) {
      return $this->create_rest_error_failed_request();
    }
	 $mapParams = [
		 'asset' => 'assets',
		 'job' => 'jobs',
     'serviceLine' => 'serviceLines',
     'clockEvents'     => 'clockEvents',
     'invoices'        => 'invoices',
    ];
    $mappedData = Servicetrade_Helper_Sideloadmapper::map_sideloaded_data( $apiResult, 'serviceRequests', $mapParams );

    $mappedResults = array();

	 foreach ( $mappedData as $result ) {
		 if ( !$result['job'] || in_array( $result['job']['status'], array( 'new', 'canceled' ) ) ) {
			 continue;
		 }
      $mappedServiceLines = array();
		$mappedServiceDescriptions = array();

      // @NOTE - the data structure here is different from the jobs calls.
      if( isset($result['serviceLine'])) {
			if ($result['description'] && array_intersect(['public', 'customer'], $result['visibility'])) {
				$mappedServiceDescriptions[] = $result['description'];
			}
        $mappedServiceLines[] = array(
          'id' => $result['serviceLine']['id'],
          'name' => $result['serviceLine']['name'],
        );
      }

		$invoiceAmount = 0;
		if ($result['job']['invoices']) {
			 foreach ($result['job']['invoices'] as $invoice) {
				if(!empty($invoice['totalPrice'])) {
				  $invoiceAmount = $invoiceAmount  + $invoice['totalPrice'];
				}
			 }
		}

    $isOnsite = false;
    $isEnroute = false;
    $onsiteStartTime = null;
    $enrouteStartTime = null;
    
    if($result['status'] === 'scheduled') {
      if(! empty($result['clockEvents']) ) {
        foreach ($result['clockEvents'] as $clock_event) {
          if($clock_event['type'] === 'clock-in' &&
            $clock_event['activity'] === 'onsite') {
              $isOnsite = true;
              $onsiteStartTime = $clock_event['time'];
          } else if($clock_event['type'] === 'clock-out' &&
            $clock_event['activity'] === 'onsite') {
            $isOnsite = false;
          } else if($clock_event['type'] === 'clock-in' &&
            $clock_event['activity'] === 'enroute') {
              $isEnroute = true;
              $enrouteStartTime = $clock_event['time'];
          } else if($clock_event['type'] === 'clock-out' &&
            $clock_event['activity'] === 'enroute') {
            $isEnroute = false;
          }
        }
      }
    }
		$serviceLinkData = ['jobId' => $result['job']['id'], 'contactId' => $contactId];
		$encryptedServiceLinkData = Servicetrade_Service_Portal_Public_Authenticated_User::encryptUserData($serviceLinkData);

		$jobDescription = in_array('description', $result['job']['visibility']) ? $result['job']['description'] : '';
		if (!$jobDescription) {
			$jobDescription = implode('<br />', $mappedServiceDescriptions);
		}

      $mappedResults[] = array(
        'id' => $result['id'],
        'uri' => $result['uri'],
				'serviceLinkData' => $encryptedServiceLinkData,
        'windowStart' => $result['windowStart'],
        'description' => $jobDescription,

        'jobType' => $result['job']['type'],
        'jobNumber' => $result['job']['number'],
        'jobTypeDisplay' => ucwords( str_replace("_", " ", $result['job']['type'])),
        'serviceLines' => $mappedServiceLines,
        'invoiceAmount' => $invoiceAmount,
        'isOnsite' => $isOnsite,
			'isEnroute' => $isEnroute
      );
    }
        
    $restResponse =  array(
      "servicerequests" => $mappedResults
    );
    return $this->create_rest_success($restResponse);
  } 


	protected function build_asset_service_requests_query() {
	  $query = [
		  'assetId' => $this->id,
		  '_sideload' => 'serviceRequest.asset,serviceRequest.job,job.clockEvents,job.invoices,serviceRequest.serviceLine',
		  'status' => 'open,closed,in_progress',
	  ];
    return '/servicerequest?' . http_build_query($query);
	}
}
