<?php

require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'includes/class-servicetrade-action.php';
require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'public/rest/class-public-rest-action.php';

/**
 * Returns the open deficiencies
 *
 * An action class.
 *
 * @link       http://www.servicetrade.com
 * @since      2.0.0
 * @package    Servicetrade_Service_Portal
 * @subpackage Servicetrade_Service_Portal/public/rest/actions
 * @author     ServiceTrade <support@servicetrade.com>
 * @example    http://localhost:8888/wp-json/servicetrade-service-portal/v2/public/deficiencies/open
 */
class Servicetrade_Service_Portal_Public_Actions_Rest_Deficiencies_Open_Get_Action extends Servicetrade_Service_Portal_Public_Rest_Action {

  private $filterLocationId;
  private $filterServiceLineId;
  
	public function __construct($filterLocationId, 
															$filterServiceLineId) {
    $this->filterLocationId = $filterLocationId;
		$this->filterServiceLineId = $filterServiceLineId;
  }


  function run() {
    $user = $this->get_authenticated_user();
    if(null === $user) {
			return $this->create_rest_error_not_authorized();
    }

	 //@todo convert to sideload
    $query = array();
    if(!empty($this->filterLocationId)) {
      $query['locationId'] = $this->filterLocationId;
    } else {
      /* The API requires a location Id. If none exists we
      return an empty result set
      */
      return new WP_REST_Response( array("deficiencies" => []), 200 );
    }

    /* 
    ** Can't be filtered per API docs 
    if(!empty($this->filterServiceLineId)) {
      $query[] = array('serviceLineId' => $this->filterServiceLineId);
    }
    */

    $location = $this->st_api()->get( '/location/' . $this->filterLocationId);
    if(empty($location) || !isset( $location['id'] )) {
      /**
       * The location was not found - we treat this as
       * a soft error and return an empty result.
       */
      return new WP_REST_Response( array("deficiencies" => []), 200 );
    }

    $apiResult = $this->st_api()->get( '/deficiency?' . http_build_query($query) );

    if(!isset( $apiResult['deficiencies'] )) {
      return $this->create_rest_error_failed_request();
    }
    $deficiencies = $apiResult['deficiencies'];

    $mappedResults = array();

    foreach ($deficiencies as $result) {

      $mappedServiceLines = array();

      if(!empty($result['serviceLine'] )) {
        $mappedServiceLines[] = array(
          'id' => $result['serviceLine']['id'],
          'name' => $result['serviceLine']['name'],
        );
      }

		// Filter fixed and invalid deficiencies
		if (in_array($result['status'], array('fixed', 'invalid'))) {
			continue;
		}

      // Filter service lines
      if(!empty($this->filterServiceLineId)) {
        $foundServiceLine = false;

        foreach($mappedServiceLines as $serviceLine) {
          if($this->filterServiceLineId == $serviceLine['id']) {
            $foundServiceLine = true;
          }
        }

        if(!$foundServiceLine) {
          continue;
        }
		}


		//@TODO quote ID, URI, amount

		$description = implode(' - ', array_filter([strtoupper($result['severity']),$result['description']]));

      $mappedResults[] = array(
        'id' => $result['id'], // The deficiency number
        'locationId' => $this->filterLocationId,
        'locationName' => $location['name'],
        'reportedOn' => $result['reportedOn'],
        'assetId' => $result['asset']['id'],
        'assetName' => $result['asset']['name'],
        'serviceLines' => $mappedServiceLines,
        'description' => $description,
        'resolution' => $result['resolution'],
        'quoteId' => null,
        'quoteUri' => null
      );
    }

    $restResponse =  array(
      "deficiencies" => $mappedResults
    );
    return new WP_REST_Response( $restResponse, 200 );
  }
}
