<?php

require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'includes/class-servicetrade-action.php';
require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'public/rest/class-public-rest-action.php';

/**
 * Returns the assets belonging to a location.
 *
 * @example
 * http://localhost:8888/wp-json/servicetrade-service-portal/v2/public/locations/1739987/assets
 *
 * @link       http://www.servicetrade.com
 * @since      2.0.0
 * @package    Servicetrade_Service_Portal
 * @subpackage Servicetrade_Service_Portal/public/rest/actions
 * @author     ServiceTrade <support@servicetrade.com>
 */
class Servicetrade_Service_Portal_Public_Actions_Rest_Location_Assets_For_Select_Get_Action extends Servicetrade_Service_Portal_Public_Rest_Action {
  private $id;

  function __construct($id) {
    assert($id !== null, "An id is required.");
    $this->id = $id;
  }

  function run() {

    $user = $this->get_authenticated_user();
    if(null === $user) {
			return $this->create_rest_error_not_authorized();
    }

    $query = [];    
    $params = $query ? http_build_query($query) : '';
    $apiResult = $this->st_api()->get( '/asset?locationId=' . $this->id . '&' . $params );
    
    if(!isset( $apiResult['assets'] )) {
      return $this->create_rest_error_failed_request();
    }
    $assets = $apiResult['assets'];

    $mappedResults = array();
    
    foreach ($assets as $result) {
      $mappedResults[] = array(
        'value' => $result['id'],
        'label' => $result['name'],
      );
    }
    return new WP_REST_Response( $mappedResults, 200 );
  }
}
