<?php

require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'includes/class-servicetrade-action.php';
require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'public/rest/class-public-rest-action.php';

/**
 * Returns the assets belonging to a location.
 *
 * @example
 * http://localhost:8888/wp-json/servicetrade-service-portal/v2/public/locations/1739987/servicerequests
 *
 * @link       http://www.servicetrade.com
 * @since      2.0.0
 * @package    Servicetrade_Service_Portal
 * @subpackage Servicetrade_Service_Portal/public/rest/actions
 * @author     ServiceTrade <support@servicetrade.com>
 */
class Servicetrade_Service_Portal_Public_Actions_Rest_Location_Servicerequests_Get_Action extends Servicetrade_Service_Portal_Public_Rest_Action {
  private $id;

  function __construct($id) {
    assert($id !== null, "An id is required.");
    $this->id = $id;
  }

  function run() {
    $user = $this->get_authenticated_user();
    if(null === $user) {
			return $this->create_rest_error_not_authorized();
    }

    $query = [];
    $params = $query ? http_build_query($query) : '';
    $apiResult = $this->st_api()->get( '/servicerequest?locationId=' . $this->id . '&' . $params );
    
    if(!isset( $apiResult['servicerequests'] )) {
      return $this->create_rest_error_failed_request();
    }
    $servicerequests = $apiResult['servicerequests'];

    $mappedResults = array();
        
		foreach ($servicerequests as $result) {
      $mappedServiceLines = array();

      // @NOTE - the data structure here is different from the jobs calls.
      if( isset($result['serviceLine'])) {
        $mappedServiceLines[] = array(
          'id' => $result['serviceLine']['id'],
          'name' => $result['serviceLine']['name'],
        );
      }

      $invoiceAmount = 0;
      foreach ((array)$result['job']['invoices'] as $invoice) {
        if(!empty($invoice['totalPrice'])) {
          $invoiceAmount = $invoiceAmount  + $invoice['totalPrice'];
        }
      }

			$isOnsite = false;
			$isEnroute = false;
			$onsiteStartTime = null;
			$enrouteStartTime = null;
			
			if($result['status'] === 'scheduled') {
				if(! empty($result['clockEvents']) ) {
					foreach ($result['clockEvents'] as $clock_event) {
						if($clock_event['type'] === 'clock-in' &&
							$clock_event['activity'] === 'onsite') {
								$isOnsite = true;
								$onsiteStartTime = $clock_event['time'];
						} else if($clock_event['type'] === 'clock-out' &&
							$clock_event['activity'] === 'onsite') {
							$isOnsite = false;
						} else if($clock_event['type'] === 'clock-in' &&
							$clock_event['activity'] === 'enroute') {
								$isEnroute = true;
								$enrouteStartTime = $clock_event['time'];
						} else if($clock_event['type'] === 'clock-out' &&
							$clock_event['activity'] === 'enroute') {
							$isEnroute = false;
						}
					}
				}
			}
			

      $mappedResults[] = array(
        'id' => $result['id'],
        'uri' => $result['uri'],
        'windowStart' => $result['windowStart'],
        'description' => $result['job']['description'],

        'jobType' => $result['job']['type'],
        'jobTypeDisplay' => ucwords( str_replace("_", " ", $result['job']['type'])),
        'serviceLines' => $mappedServiceLines,
        'invoiceAmount' => $invoiceAmount,
        'isOnsite' => $isOnsite,
				'isEnroute' => $isEnroute
      );
    }
        
    $restResponse =  array(
      "servicerequests" => $mappedResults
    );
    return new WP_REST_Response( $restResponse, 200 );
  } 
}
