<?php

require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'includes/class-servicetrade-action.php';
require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'public/rest/class-public-rest-action.php';

/**
 * Returns the open quotes
 * Good test data:
 * http://localhost:8888/wp-json/servicetrade-service-portal/v2/public/quotes/open?location-id=97906
 * http://localhost:8888/wp-json/servicetrade-service-portal/v2/public/quotes/open?service-line-id=70&location-id=97906
 * http://localhost:8888/wp-json/servicetrade-service-portal/v2/public/quotes/open?service-line-id=70
 * http://localhost:8888/wp-json/servicetrade-service-portal/v2/public/quotes/open
 *
 * An action class.
 *
 * @link       http://www.servicetrade.com
 * @since      2.0.0
 * @package    Servicetrade_Service_Portal
 * @subpackage Servicetrade_Service_Portal/public/rest/actions
 * @author     ServiceTrade <support@servicetrade.com>
 */
class Servicetrade_Service_Portal_Public_Actions_Rest_Quotes_Open_Get_Action extends Servicetrade_Service_Portal_Public_Rest_Action {

  private $filterLocationId;
  private $filterServiceLineId;
  
	public function __construct($filterLocationId, 
															$filterServiceLineId) {
    $this->filterLocationId = $filterLocationId;
		$this->filterServiceLineId = $filterServiceLineId;
  }

  function run() {
    $user = $this->get_authenticated_user();
    if(null === $user) {
			return $this->create_rest_error_not_authorized();
    }
		$contactId = $user->getContactId();

    $query = array(
      'status' => 'submitted'
    );

    if(!empty($this->filterLocationId)) {
      $query['locationId'] = $this->filterLocationId;
	 } else {
		 $locations = $user->getContactLocations();
		 if ($locations) {
			 $locationIds = array_map(function($l) { return $l['id']; }, $locations);
			 $query['locationId'] = implode(',', $locationIds);
		 } else {
			return new WP_Error( 'servicetrade_failed_request' ,'The plugin could not retrieve data from the servicetrade API', array( 'status' => 503 ) );
		 }
	 }

    $apiResult = $this->st_api()->get( '/quote?' . http_build_query($query) );

    if(!isset( $apiResult['quotes'] )) {
      return $this->create_rest_error_failed_request();
    }
    $quotes = $apiResult['quotes'];

    $mappedResults = array();

    foreach ($quotes as $result) {
      $mappedServiceLines = array();
      
      foreach ($result['serviceLines'] as $serviceLine) {
        $mappedServiceLines[] = array(
          'id' => $serviceLine['id'],
          'name' => $serviceLine['name'],
        );
      }

      // Filter service lines
      if(!empty($this->filterServiceLineId)) {
				$foundServiceLine = false;

				foreach($mappedServiceLines as $serviceLine) {
					if($this->filterServiceLineId == $serviceLine['id']) {
						$foundServiceLine = true;
					}
				}

				if(!$foundServiceLine) {
					continue;
				}
			}

		$quoteLinkData = ['quoteId' => $result['id'], 'contactId' => $contactId];
		$encryptedQuoteLinkData = Servicetrade_Service_Portal_Public_Authenticated_User::encryptUserData($quoteLinkData);

      $mappedResults[] = array(
        'id' => $result['id'], // The quote number
        'uri' => $result['uri'], // The quote number
        'quoteLinkData' => $encryptedQuoteLinkData,
        'description' => $result['description'],
        'totalPrice' => $result['totalPrice'], // IS A STRING
        'locationId' => $result['location']['id'],
        'locationName' => $result['location']['name'],
        'expiresOn' => $result['expiresOn'],
        'serviceLines' => $mappedServiceLines
      );
    }

    $restResponse =  array(
      "quotes" => $mappedResults,
      "result" => $apiResult 
    );
    return new WP_REST_Response( $restResponse, 200 );
  }
}
