<?php

require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'includes/class-servicetrade-action.php';
require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'public/rest/class-public-rest-action.php';

/**
 * Starts the forgot password sequence.
 *
 * @link       http://www.servicetrade.com
 * @since      2.0.0
 * @package    Servicetrade_Service_Portal
 * @subpackage Servicetrade_Service_Portal/public/rest/actions
 * @author     ServiceTrade <support@servicetrade.com>
 */
class Servicetrade_Service_Portal_Public_Actions_Rest_User_Forgot_Password_Post_Action extends Servicetrade_Service_Portal_Public_Rest_Action {

  public function __construct($user_login ) {
    $this->user_login = $user_login;
  }

  function run() {

    $user = get_user_by('email', $this->user_login);

    if (!$user) {
      return new WP_Error( 'servicetrade_cant_find_password_reset_user', 'Could not find your email address.', 
                          array( 'status' => 422, 
                          'errors' => array('login' => 'Could not find your email address.'
      ) ) );
    }

    $userData = get_userdata($user->data->ID);
    $user_login = $userData->user_login;
    $user_email = $userData->user_email;
    $key = get_password_reset_key( $userData );

    $message = __('Someone requested that the password be reset for the following account:') . "\r\n\r\n";
    $message .= network_home_url( '/' ) . "\r\n\r\n";
    $message .= sprintf(__('Username: %s'), $user_login) . "\r\n\r\n";
    $message .= __('If this was a mistake, just ignore this email and nothing will happen.') . "\r\n\r\n";
    $message .= __('To reset your password, visit the following address:') . "\r\n\r\n";
    $message .= network_site_url("wp-login.php?action=rp&key=$key&login=" . rawurlencode($user_login), 'login');

    if ( is_multisite() )
      $blogname = $GLOBALS['current_site']->site_name;
    else
      $blogname = wp_specialchars_decode(get_option('blogname'), ENT_QUOTES);

    $title = sprintf( __('[%s] Password Reset'), $blogname );

    $title = apply_filters('retrieve_password_title', $title);
    $message = apply_filters('retrieve_password_message', $message, $key);

    if ( $message && !wp_mail($user_email, $title, $message) ) {
      return new WP_Error( 'servicetrade_cant_send_password_reset', 'The email could not be sent.', 
                          array( 'status' => 422, 
                          'errors' => array('login' => 'The email could not be sent.'
      ) ) );
    }

    return new WP_REST_Response( array(), 200 );
  } 
}
