(function( $ ) {
	'use strict';

	/**
	 * Manages data table related functionality.
	 * Data tables are driven entirely declaratively.
	 * 
	 * All of the code for your admin-facing JavaScript source
	 * should reside in this file.
	 *
	 * Note: It has been assumed you will write jQuery code here, so the
	 * $ function reference has been prepared for usage within the scope
	 * of this function.
	 *
	 * This enables you to define handlers, for when the DOM is ready:
	 *
	 * $(function() {
	 *
	 * });
	 *
	 * When the window is loaded:
	 *
	 * $( window ).load(function() {
	 *
	 * });
	 *
	 * ...and/or other possibilities.
	 *
	 * Ideally, it is not considered best practise to attach more than a
	 * single DOM-ready or window-load handler for a particular page.
	 * Although scripts in the WordPress core, Plugins and Themes may be
	 * practising this, we should strive to set a better example in our own work.
	 */

	var dataTableRenderers = {
		status: function (data, type, row) {
			if (data === 'active') {
					return 'Active';
			} else {
					return 'Inactive';
			}
		},
		viewQuotes:  function (data, type, row) {
			if (type === 'display') {
					return '<input type="checkbox" class="editor-seequotes">';
			}
			return data;
		},
		viewInvoices: function (data, type, row) {
			if (type === 'display') {
					return '<input type="checkbox" class="editor-seeinvoices">';
			}
			return data;
		}
	};

  $(function() {
		var dataId = null,
				loadedData = null;

		$('.servicetradeViewDataTable').each(function(i,v) {
			dataId = $(v).data('id');
			loadedData = JSON.parse($('#' + dataId).html());
			console.log(JSON.stringify(loadedData));

			$(v).DataTable({
				data: loadedData,
				columns: [
					{
						"data": "username",
					  "title": "Username"},
					{
						"data": "email",
						"title": "Email"},
					{
							"data": "status",
							render: dataTableRenderers['status']
					},
					{
							data: "see_job",
							render: function (data, type, row) {
									if (type === 'display') {
											return '<input type="checkbox" class="editor-seejobs">';
									}
									return data;
							},
							className: "dt-body-center"
					},
					{
						title: 'View Quotes',
						data: "see_quote",
						render: dataTableRenderers['viewQuotes'],
						className: "dt-body-center"
					},
					{
						data: "see_invoice",
						title: 'View Invoices',
						render: dataTableRenderers['viewInvoices'],
						className: "dt-body-center"
					},
					{
							data: {"id": "id", "status": "status"},
							render: function (data, type, row) {
									if (data.status === 'A') {
											return '<a onclick="processrequest(\'deactiveUser\',' + data.id + ')" style="cursor: pointer;">Deactivate</a>';
									} else {
					 return '<a onclick="processrequest(\'activeUser\',' + data.id + ')" style="cursor: pointer;">Activate</a> ' +
						 '<a onclick="processrequest(\'deleteUser\',' + data.id + ')" style="color: red; cursor: pointer;">Delete</a>';

									}
							},
							className: "dt-body-center"
					}

				]}
			);
		});



/**
 *             var usertable=jQuery('#userstable').DataTable({
                data: <?php echo json_encode($all_results) ?>,
                "columns": [
                    {"data": "username"},
                    {"data": "email"},
                    {
                        data: "status",
                        render: function (data, type, row) {
                            if (data === 'A') {
                                return 'Active';
                            } else {
                                return 'Inactive';
                            }
                        }
                    },
                    {
                        data: "see_job",
                        render: function (data, type, row) {
                            if (type === 'display') {
                                return '<input type="checkbox" class="editor-seejobs">';
                            }
                            return data;
                        },
                        className: "dt-body-center"
                    },
                    {
                        data: "see_quote",
                        render: function (data, type, row) {
                            if (type === 'display') {
                                return '<input type="checkbox" class="editor-seequotes">';
                            }
                            return data;
                        },
                        className: "dt-body-center"
                    },
                    {
                        data: "see_invoice",
                        render: function (data, type, row) {
                            if (type === 'display') {
                                return '<input type="checkbox" class="editor-seeinvoices">';
                            }
                            return data;
                        },
                        className: "dt-body-center"
                    },
                    {
                        data: {"id": "id", "status": "status"},
                        render: function (data, type, row) {
                            if (data.status === 'A') {
                                return '<a onclick="processrequest(\'deactiveUser\',' + data.id + ')" style="cursor: pointer;">Deactivate</a>';
                            } else {
										 return '<a onclick="processrequest(\'activeUser\',' + data.id + ')" style="cursor: pointer;">Activate</a> ' +
											 '<a onclick="processrequest(\'deleteUser\',' + data.id + ')" style="color: red; cursor: pointer;">Delete</a>';

                            }
                        },
                        className: "dt-body-center"
                    }
                ],
                "columnDefs": [
                    { "width": "14%", "targets": 6 },
                    { "visible": false, "targets": 4 }  //@todo remove once quotes are visible
                ],
                rowCallback: function (row, data) {
                    // Set the checked state of the checkbox in the table
                    jQuery('input.editor-seejobs', row).prop('checked', data.see_job == 1);
                    jQuery('input.editor-seequotes', row).prop('checked', data.see_quote == 1);
                    jQuery('input.editor-seeinvoices', row).prop('checked', data.see_invoice == 1);
                }
            });

            jQuery('#userstable').on( 'change', 'input.editor-seejobs', function () {
                var tr = jQuery(this).closest('tr');
                var row = usertable.row(tr);
                var rowData = row.data();
                jQuery("#userid").attr("value", rowData.id);

                if(jQuery(this).prop( 'checked' )==true) {
                    jQuery("#action").attr("value", 'seejob');
                }else{
                    jQuery("#action").attr("value", 'cantseejob');
                }

                processpermisson();
            });

            jQuery('#userstable').on( 'change', 'input.editor-seeinvoices', function () {
                var tr = jQuery(this).closest('tr');
                var row = usertable.row(tr);
                var rowData = row.data();
                jQuery("#userid").attr("value", rowData.id);

                if(jQuery(this).prop( 'checked' )==true) {
                    jQuery("#action").attr("value", 'seeinvoice');
                }else{
                    jQuery("#action").attr("value", 'cantseeinvoice');
                }

                processpermisson();
            });

 */

  });

})( jQuery );
